==> apache-tinkerpop-3.6.5-src.zip: tinkerpop-3.6.5/gremlin-dotnet/src/Gremlin.Net/Structure/IO/GraphSON/DecimalConverter.cs <==
﻿#region License

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#endregion

using System.Globalization;
using System.Text.Json;

namespace Gremlin.Net.Structure.IO.GraphSON
{
    internal class DecimalConverter : NumberConverter<decimal>
    {
        protected override string GraphSONTypeName => "BigDecimal";
        protected override string Prefix => "gx";
        protected override bool StringifyValue => true;
        protected override dynamic FromJsonElement(JsonElement graphson)
        {
            if (graphson.ValueKind == JsonValueKind.String)
            {
                return decimal.Parse(graphson.GetString(), CultureInfo.InvariantCulture);
            }
            return graphson.GetDecimal();
        }
    }
}

==> apache-tinkerpop-3.7.5-src.zip: tinkerpop-3.7.5/gremlin-dotnet/src/Gremlin.Net/Structure/IO/GraphSON/DecimalConverter.cs <==
﻿#region License

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#endregion

using System.Globalization;
using System.IO;
using System.Text.Json;

namespace Gremlin.Net.Structure.IO.GraphSON
{
    internal class DecimalConverter : NumberConverter<decimal>
    {
        protected override string GraphSONTypeName => "BigDecimal";
        protected override string Prefix => "gx";
        protected override bool StringifyValue => true;
        protected override dynamic FromJsonElement(JsonElement graphson)
        {
            if (graphson.ValueKind == JsonValueKind.String)
            {
                return decimal.Parse(
                    graphson.GetString() ?? throw new IOException("Read null but expected a decimal string"),
                    CultureInfo.InvariantCulture);
            }
            return graphson.GetDecimal();
        }
    }
}
